@@ -29,7 +29,7 @@ impl<M: ManagedTypeApi> EsdtTokenPayment<M> {
     }
 
     pub fn new(token_identifier: TokenIdentifier<M>, token_nonce: u64, amount: BigUint<M>) -> Self {
-        let token_type = if amount != 0 && token_identifier.is_valid_esdt_identifier() {
+        let token_type = if amount != 0 && token_identifier.is_esdt() {
             if token_nonce == 0 {
                 EsdtTokenType::Fungible
             } else if amount == 1u64 {
