@@ -3,6 +3,7 @@ mod code_metadata;
 mod esdt_local_role;
 mod esdt_token_data;
 mod esdt_token_payment;
+mod esdt_token_payment_multi_arg;
 mod esdt_token_type;
 mod h256;
 mod h256_address;
@@ -14,6 +15,7 @@ pub use code_metadata::CodeMetadata;
 pub use esdt_local_role::EsdtLocalRole;
 pub use esdt_token_data::EsdtTokenData;
 pub use esdt_token_payment::EsdtTokenPayment;
+pub use esdt_token_payment_multi_arg::EsdtTokenPaymentMultiArg;
 pub use esdt_token_type::EsdtTokenType;
 pub use h256::H256;
 pub use h256_address::Address;
